==> nextcloud-17.0.2.tar.bz2: nextcloud/apps/systemtags/l10n/bg.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Етикети",
    "Update" : "Актуализирай",
    "Create" : "Създай",
    "Select tag…" : "Изберете етикет...",
    "Added system tag {systemtag}" : "Добавен системен етикет {systemtag}",
    "Added system tag %1$s" : "Добавен системен етикет %1$s",
    "%1$s added system tag %2$s" : "%1$s добави системен етикет %2$s",
    "{actor} added system tag {systemtag}" : "{actor} добави системен етикет {systemtag}",
    "Removed system tag {systemtag}" : "Премахнат системен етикет {systemtag}",
    "Removed system tag %1$s" : "Премахнат системен етикет %1$s",
    "%1$s removed system tag %2$s" : "%1$s премахна системен етикет %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} премахна системен етикет {systemtag}",
    "You created system tag %1$s" : "Създадохте системен етикет %1$s",
    "You created system tag {systemtag}" : "Създадохте системен етикет {systemtag}",
    "%1$s created system tag %2$s" : "%1$s създаде системен етикет %2$s",
    "{actor} created system tag {systemtag}" : "{actor} създаде системен етикет {systemtag}",
    "You deleted system tag %1$s" : "Изтрихте системен етикет %1$s",
    "You deleted system tag {systemtag}" : "Изтрихте системен етикет {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s изтри системен етикет %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} изтри системен етикет {systemtag}",
    "You updated system tag %2$s to %1$s" : "Актуализирахте системен етикет %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Актуализирахте системен етикет {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s акутализиран системен етикет %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} Актуализира системен етикет {oldsystemtag} на {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Добавихте системен етикет %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Добавихте системен етикет {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s добави системен етикет %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} добави системен етикет {systemtag} на {file}",
    "You removed system tag %2$s from %1$s" : "Премахнахте системен етикет %2$s от %1$s",
    "You removed system tag {systemtag} from {file}" : "Премахнахте системен етикет {systemtag} от {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s премахна системни етикет %3$s от %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} премахна системен етикет {systemtag} от {file}",
    "<strong>System tags</strong> for a file have been modified" : "Промяна на <strong>системни етикети</strong> за файл",
    "Tagged files" : "Отбелязани файлове",
    "Select tags to filter by" : "Филтриране по етикет",
    "No tags found" : "Не са открити етикети",
    "Please select tags to filter by" : "Моля изберете етикети, за филтрирането",
    "No files found for the selected tags" : "Няма намерени файлове за избраните етикети",
    "Select tag …" : "Изберете етикет...",
    "Create a new tag" : "Създаване на нов етикет",
    "Name" : "Име",
    "Public" : "Публичен",
    "Restricted" : "Ограничен",
    "Invisible" : "Невидим",
    "Delete" : "Изтриване",
    "Reset" : "Нулирай",
    "No files in here" : "Няма файлове",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Size" : "Размер",
    "Modified" : "Променен на"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/systemtags/l10n/bg.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Името на етикет е празно",
    "Update" : "Актуализирай",
    "Create" : "Създай",
    "Select tag …" : "Изберете етикет...",
    "System tag %1$s added by the system" : "Системен етикет %1$s, добавен от системата",
    "Added system tag {systemtag}" : "Добавен системен етикет {systemtag}",
    "Added system tag %1$s" : "Добавен системен етикет %1$s",
    "%1$s added system tag %2$s" : "%1$s добави системен етикет %2$s",
    "{actor} added system tag {systemtag}" : "{actor} добави системен етикет {systemtag}",
    "System tag %1$s removed by the system" : "Системeн етикет %1$s е премахнат от системата",
    "Removed system tag {systemtag}" : "Премахнат системен етикет {systemtag}",
    "Removed system tag %1$s" : "Премахнат системен етикет %1$s",
    "%1$s removed system tag %2$s" : "%1$s премахна системен етикет %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} премахна системен етикет {systemtag}",
    "You created system tag %1$s" : "Създадохте системен етикет %1$s",
    "You created system tag {systemtag}" : "Създадохте системен етикет {systemtag}",
    "%1$s created system tag %2$s" : "%1$s създаде системен етикет %2$s",
    "{actor} created system tag {systemtag}" : "{actor} създаде системен етикет {systemtag}",
    "You deleted system tag %1$s" : "Изтрихте системен етикет %1$s",
    "You deleted system tag {systemtag}" : "Изтрихте системен етикет {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s изтри системен етикет %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} изтри системен етикет {systemtag}",
    "You updated system tag %2$s to %1$s" : "Актуализирахте системен етикет %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Актуализирахте системен етикет {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s акутализиран системен етикет %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} Актуализира системен етикет {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системният етикет %2$s беше добавен към %1$s от системата",
    "System tag {systemtag} was added to {file} by the system" : "Системният етикет {systemtag} беше добавен към {file} от системата",
    "You added system tag %2$s to %1$s" : "Добавихте системен етикет %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Добавихте системен етикет {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s добави системен етикет %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} добави системен етикет {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системният етикет %2$s беше премахнат от %1$s от системата",
    "System tag {systemtag} was removed from {file} by the system" : "Системният етикет {systemtag} беше премахнат от {file} от системата",
    "You removed system tag %2$s from %1$s" : "Премахнахте системен етикет %2$s от %1$s",
    "You removed system tag {systemtag} from {file}" : "Премахнахте системен етикет {systemtag} от {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s премахна системни етикет %3$s от %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} премахна системен етикет {systemtag} от {file}",
    "%s (restricted)" : "%s (ограничен)",
    "%s (invisible)" : "%s (невидим)",
    "<strong>System tags</strong> for a file have been modified" : "Промяна на <strong>системни етикети</strong> за файл",
    "Tags" : "Етикети",
    "All tagged %s …" : "Всички маркирани %s ...",
    "tagged %s" : "маркиран %s",
    "Collaborative tags" : "Съвместни етикети",
    "Collaborative tagging functionality which shares tags among users." : "Функция за съвместно етикетиране/маркиране/, която споделя етикети между потребителите.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функция за съвместно етикетиране, която споделя етикети между потребителите. Чудесно е за екипи.\n\t(Ако сте доставчик с инсталация с множество клиенти, препоръчваме ви да деактивирате това приложение, тъй като етикетите се споделят.)",
    "Tagged files" : "Отбелязани файлове",
    "Select tags to filter by" : "Филтриране по етикет",
    "No tags found" : "Не са открити етикети",
    "Please select tags to filter by" : "Моля изберете етикети, за филтрирането",
    "No files found for the selected tags" : "Няма намерени файлове за избраните етикети",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Етикетите за сътрудничество са достъпни за всички потребители. Ограничените етикети са видими за потребителите, но не могат да бъдат присвоени от тях. Невидимите етикети са за вътрешна употреба, тъй като потребителите не могат да ги виждат или присвояват.",
    "Create a new tag" : "Създаване на нов етикет",
    "Name" : "Име",
    "Public" : "Публичен",
    "Restricted" : "Ограничен",
    "Invisible" : "Невидим",
    "Delete" : "Изтриване",
    "Reset" : "Нулирай",
    "No files in here" : "Няма файлове",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Size" : "Размер",
    "Modified" : "Променен на"
},
"nplurals=2; plural=(n != 1);");
